MultiResultTracker
==================

.. currentmodule:: pykeen.trackers

.. autoclass:: MultiResultTracker
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~MultiResultTracker.end_run
      ~MultiResultTracker.get_configuration
      ~MultiResultTracker.log_metrics
      ~MultiResultTracker.log_params
      ~MultiResultTracker.start_run

   .. rubric:: Methods Documentation

   .. automethod:: end_run
   .. automethod:: get_configuration
   .. automethod:: log_metrics
   .. automethod:: log_params
   .. automethod:: start_run
